@@ -1,11 +1,11 @@
 /* VGraphic.m
  * Graphic object - root class
  *
- * Copyright (C) 1996-2003 by vhf interservice GmbH
+ * Copyright (C) 1996-2006 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1996-01-29
- * modified: 2003-06-26
+ * modified: 2006-02-16
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -64,7 +64,7 @@ static int dkgrayRectCount = 0;
         {   blackRectSize = 16;
 	    blackRectList = NSZoneMalloc((NSZone *)[(NSObject *)NSApp zone], (blackRectSize) * sizeof(NSRect));
 	}
-        else
+        else if ( blackRectCount >= blackRectSize )
         {
 	    while (blackRectCount >= blackRectSize)
                 blackRectSize <<= 1;
@@ -78,7 +78,7 @@ static int dkgrayRectCount = 0;
         {   dkgrayRectSize = 16;
             dkgrayRectList = NSZoneMalloc((NSZone *)[(NSObject *)NSApp zone], (dkgrayRectSize) * sizeof(NSRect));
         }
-        else
+        else if ( dkgrayRectCount >= dkgrayRectSize )
         {
             while (dkgrayRectCount >= dkgrayRectSize)
                 dkgrayRectSize <<= 1;
@@ -722,7 +722,7 @@ static void drawKnob( NSPoint origin, BOOL direct, BOOL selectedKnob, float scal
     return ([a count]>1) ? a : nil;
 }
 
-- getListOfObjectsSplittedFrom:(NSPoint*)pArray :(int)iCnt
+- (NSMutableArray*)getListOfObjectsSplittedFrom:(NSPoint*)pArray :(int)iCnt
 {
     NSLog(@"VGraphic, -getListOfObjectsSplittedFrom not implemented!");
     return nil;
@@ -857,18 +857,23 @@ static void drawKnob( NSPoint origin, BOOL direct, BOOL selectedKnob, float scal
 {   NSMutableDictionary	*plist = [NSMutableDictionary dictionaryWithCapacity:10];
 
     [plist setObject:NSStringFromClass([self class]) forKey:@"Class"];
-    [plist setObject:propertyListFromNSColor(color) forKey:@"color"];
-    [plist setObject:propertyListFromFloat(width) forKey:@"width"];
+    if (color != [NSColor blackColor])
+        [plist setObject:propertyListFromNSColor(color) forKey:@"color"];
+    if (width)
+        [plist setObject:propertyListFromFloat(width) forKey:@"width"];
     if (isLocked) [plist setObject:@"1" forKey:@"isLocked"];
     if (isDirectionCCW) [plist setObject:@"1" forKey:@"ccw"];
+    //if (!isDirectionCCW) [plist setObject:@"1" forKey:@"cw"];
     return plist;
 }
 - (id)initFromPropertyList:(id)plist inDirectory:(NSString *)directory
 {
     pmList = [NSMutableArray new];
-    color = colorFromPropertyList([plist objectForKey:@"color"], [self zone]);
+    if (!(color = colorFromPropertyList([plist objectForKey:@"color"], [self zone])))
+        [self setColor:[NSColor blackColor]];
     width = [plist floatForKey:@"width"];
     isLocked = ([plist objectForKey:@"isLocked"]) ? YES : NO;
+    //isDirectionCCW = ([plist objectForKey:@"cw"]) ? NO : YES;
     isDirectionCCW = ([plist objectForKey:@"ccw"] || [plist objectForKey:@"isDirectionCCW"]) ? YES : NO;
     dirty = YES;
     return self;
